@@ -6,6 +6,22 @@ penguins2 <-
   palmerpenguins::penguins %>%
   dplyr::filter(!is.na(sex), !is.na(bill_depth_mm), !is.na(bill_length_mm))
 
+penguins3 <-
+  palmerpenguins::penguins %>%
+  dplyr::filter(!is.na(sex), !is.na(bill_depth_mm), !is.na(bill_length_mm)) %>%
+  dplyr::rename(`bill length` = bill_length_mm, `bill depth` = bill_depth_mm,
+                `sex of penguin` = sex)
+
+TestData <- dplyr::bind_rows(
+  mosaic::do(20) * tibble(a = "A", b = "E", c = "X"),
+  mosaic::do(20) * tibble(a = "A", b = "E", c = "Z"),
+  mosaic::do(10) * tibble(a = "A", b = "F", c = "X"),
+  mosaic::do(10) * tibble(a = "A", b = "F", c = "Z"),
+  mosaic::do(5)  * tibble(a = "B", b = "E", c = "X"),
+  mosaic::do(10) * tibble(a = "B", b = "E", c = "Z"),
+  mosaic::do(15) * tibble(a = "B", b = "F", c = "X"),
+  mosaic::do(10) * tibble(a = "B", b = "F", c = "Z"),
+)
 
 test_that(
   "gf_abline()", {
@@ -684,7 +700,7 @@ test_that(
     )
     wrapped_expect_doppelganger(
       "gf_dhistogramh2a",
-      gf_dhistogram(bill_length_mm ~ stat(ndensity), data = penguins2)
+      gf_dhistogramh(bill_length_mm ~ stat(ndensity), data = penguins2)
     )
   }
 )
@@ -939,3 +955,80 @@ test_that(
   }
 )
 
+
+test_that(
+  "non-syntactic names", {
+    wrapped_expect_doppelganger(
+      "gf_point() with facets",
+      gf_point(`bill length` ~ `bill depth` | `sex of penguin`, data = penguins3)
+    )
+    wrapped_expect_doppelganger(
+      "gf_histogram() with facets",
+      gf_histogram(~ `bill depth` | `sex of penguin` ~ ., data = penguins3)
+    )
+    wrapped_expect_doppelganger(
+      "gf_density() with fill",
+      gf_density( ~ `bill depth`, fill = ~ `sex of penguin`, data = penguins3)
+    )
+  }
+)
+
+test_that(
+  "ellipses", {
+    wrapped_expect_doppelganger(
+      "multiple ellipses of two different types",
+      gf_point(eruptions ~ waiting, data = faithful, color = ~ (eruptions > 3)) %>%
+        gf_ellipse(type = "norm", linetype = ~ "norm") %>%
+        gf_ellipse(type = "t",    linetype = ~ "t")
+    )
+  }
+)
+
+
+test_that(
+  "gf_props() and denom",
+  {
+    wrapped_expect_doppelganger(
+      "proportions within panel (dodge)",
+      TestData %>% gf_props( ~ a | b ~ c, position = "dodge",
+                      title = "proportions within panel")
+    )
+    wrapped_expect_doppelganger(
+      "proportions within fill (dodge)",
+      TestData %>% gf_props( ~ a | b ~ c, fill = ~ b, position = "dodge", denom = ~ fill,
+                title = "proportions within fill")
+    )
+    wrapped_expect_doppelganger(
+      "proportions within all (dodge)",
+      TestData %>% gf_props( ~ a | b, fill = ~ c, position = "dodge", denom = ~ 1,
+                      title = "proportions within all")
+
+    )
+    wrapped_expect_doppelganger(
+      "proportions within fill (facet grid)",
+      TestData %>% gf_props( ~ a | b ~ c, fill = ~ b, denom = ~ fill,
+                      title = "proportions within fill")
+
+    )
+    wrapped_expect_doppelganger(
+      "proportions within fill (facet grid and group)",
+      TestData %>% gf_props( ~ a | b ~ c, fill = ~ c, group = ~b, denom = ~ fill,
+                      title = "proportions within fill")
+    )
+    wrapped_expect_doppelganger(
+      "proportions within group (facet grid)",
+      TestData %>% gf_props( ~ a | b ~ c, fill = ~ c, group = ~b, denom = ~ group,
+                      title = "proportions in group (b = E or F)")
+    )
+  }
+)
+
+
+
+
+
+
+
+
+
+
